@@ -23,6 +23,13 @@ import requests
 from .intelligence import IntelligentRouter, get_router
 from .node_health import NodeHealthMonitor, normalize_model_name
 from .vram_monitor import VRAMMonitor
+from .network_observer import (
+    log_ollama_request,
+    log_ollama_response,
+    log_ollama_error,
+    log_node_health_check,
+    log_node_status_change,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -77,6 +84,10 @@ class OllamaPool:
         self._vram_refresh_interval = 30  # seconds
         self._vram_refresh_enabled = True
 
+        # Health check configuration
+        self._health_check_interval = 30  # seconds - check node health every 30s
+        self._health_check_enabled = True
+
         # Enhanced stats tracking with performance metrics
         self.stats = {
             "total_requests": 0,
@@ -97,10 +108,18 @@ class OllamaPool:
         )
         self._vram_refresh_thread.start()
 
+        # Start background health check thread for live dashboard updates
+        self._health_check_thread = threading.Thread(
+            target=self._health_check_loop,
+            daemon=True,
+            name="OllamaPool-Health-Monitor"
+        )
+        self._health_check_thread.start()
+
         logger.info(
             f"OllamaPool initialized with {len(self.nodes)} nodes "
             f"(intelligent_routing={'enabled' if enable_intelligent_routing else 'disabled'}, "
-            f"vram_monitoring=enabled, gpu_type={self.vram_monitor.gpu_type})"
+            f"vram_monitoring=enabled, health_checks=enabled, gpu_type={self.vram_monitor.gpu_type})"
         )
 
     @classmethod
@@ -265,6 +284,16 @@ class OllamaPool:
             # Track request start time
             start_time = time.time()
 
+            # Log request to observer
+            model = data.get("model", "unknown")
+            operation = endpoint.split("/")[-1]  # "chat", "generate", etc.
+            log_ollama_request(
+                backend=node_key,
+                model=model,
+                operation=operation,
+                priority=priority
+            )
+
             try:
                 logger.debug(f"Request to {url}")
 
@@ -316,6 +345,14 @@ class OllamaPool:
                         f"avg: {self.stats['node_performance'][node_key]['latency_ms']:.1f}ms)"
                     )
 
+                    # Log response to observer
+                    log_ollama_response(
+                        backend=node_key,
+                        model=model,
+                        latency_ms=latency_ms,
+                        status_code=response.status_code
+                    )
+
                     # Record performance for router learning
                     if self.router and "model" in data:
                         task_type = (
@@ -332,12 +369,28 @@ class OllamaPool:
                     errors.append(f"{url}: HTTP {response.status_code}")
                     self._record_failure(node_key, latency_ms)
 
+                    # Log error to observer
+                    log_ollama_error(
+                        backend=node_key,
+                        model=model,
+                        error=f"HTTP {response.status_code}",
+                        latency_ms=latency_ms
+                    )
+
             except Exception as e:
                 latency_ms = (time.time() - start_time) * 1000
                 errors.append(f"{url}: {str(e)}")
                 logger.debug(f"Request failed: {e}")
                 self._record_failure(node_key, latency_ms)
 
+                # Log error to observer
+                log_ollama_error(
+                    backend=node_key,
+                    model=model,
+                    error=str(e),
+                    latency_ms=latency_ms
+                )
+
             finally:
                 # Decrement active request counter (always runs)
                 with self._lock:
@@ -579,6 +632,105 @@ class OllamaPool:
 
         logger.debug("VRAM monitoring thread stopped")
 
+    def _health_check_loop(self):
+        """Background thread to periodically check node health for live dashboard updates."""
+        logger.debug("Health check monitoring thread started")
+
+        while self._health_check_enabled:
+            try:
+                time.sleep(self._health_check_interval)
+
+                # Check health of all nodes
+                with self._lock:
+                    for node in self.nodes:
+                        node_key = f"{node['host']}:{node['port']}"
+
+                        if node_key in self.stats["node_performance"]:
+                            # Get current performance data
+                            perf_data = self.stats["node_performance"][node_key]
+
+                            # Ping node with lightweight /api/tags request
+                            start_time = time.time()
+                            try:
+                                url = f"http://{node['host']}:{node['port']}/api/tags"
+                                response = requests.get(url, timeout=2)
+                                latency_ms = (time.time() - start_time) * 1000
+
+                                if response.ok:
+                                    # Check for status change
+                                    old_status = "offline" if not perf_data.get("available", True) else "healthy"
+                                    new_status = "healthy"
+
+                                    # Update health status
+                                    self.stats["node_performance"][node_key]["available"] = True
+                                    self.stats["node_performance"][node_key]["latency_ms"] = latency_ms
+
+                                    # Update health monitor baseline
+                                    self.health_monitor.update_baseline(
+                                        node_key, latency_ms, is_gpu=True
+                                    )
+
+                                    # Log health check to observer
+                                    log_node_health_check(
+                                        backend=node_key,
+                                        status=new_status,
+                                        latency_ms=latency_ms
+                                    )
+
+                                    # Log status change if needed
+                                    if old_status != new_status:
+                                        log_node_status_change(
+                                            backend=node_key,
+                                            old_status=old_status,
+                                            new_status=new_status
+                                        )
+
+                                    logger.debug(
+                                        f"✓ Health check {node_key}: {latency_ms:.0f}ms"
+                                    )
+                                else:
+                                    # Check for status change
+                                    old_status = "healthy" if perf_data.get("available", True) else "offline"
+                                    new_status = "offline"
+
+                                    # Node returned error
+                                    self.stats["node_performance"][node_key]["available"] = False
+
+                                    # Log health check failure to observer
+                                    log_node_health_check(
+                                        backend=node_key,
+                                        status=new_status,
+                                        latency_ms=latency_ms,
+                                        error=f"HTTP {response.status_code}"
+                                    )
+
+                                    # Log status change if needed
+                                    if old_status != new_status:
+                                        log_node_status_change(
+                                            backend=node_key,
+                                            old_status=old_status,
+                                            new_status=new_status
+                                        )
+
+                                    logger.warning(
+                                        f"⚠️  Health check {node_key}: HTTP {response.status_code}"
+                                    )
+
+                            except requests.exceptions.Timeout:
+                                # Node timed out
+                                self.stats["node_performance"][node_key]["available"] = False
+                                logger.warning(f"⚠️  Health check {node_key}: timeout (>2s)")
+
+                            except requests.exceptions.RequestException as e:
+                                # Node unreachable
+                                self.stats["node_performance"][node_key]["available"] = False
+                                logger.warning(f"⚠️  Health check {node_key}: unreachable ({e})")
+
+            except Exception as e:
+                logger.error(f"Health check loop error: {e}")
+
+        logger.debug("Health check monitoring thread stopped")
+
     def _record_failure(self, node_key: str, latency_ms: float):
         """Record a failed request for a node."""
         with self._lock:
