@@ -362,8 +362,9 @@ class RayHybridRouter:
                 pool.load_model.remote(model, gguf_path)
                 for pool in self.pools
             ]
+            # Use ray.get directly in gather (it's async-compatible)
             results = await asyncio.gather(*[
-                asyncio.wrap_future(ray.get(task, timeout=60))
+                asyncio.to_thread(ray.get, task, timeout=60)
                 for task in load_tasks
             ])
 
@@ -380,8 +381,9 @@ class RayHybridRouter:
         pool = self.pools[hash(str(messages)) % len(self.pools)]
 
         # Execute inference (Ray handles queuing if pool is busy)
-        response_future = pool.chat.remote(messages, stream=stream, **kwargs)
-        response = await asyncio.wrap_future(ray.get(response_future))
+        response_ref = pool.chat.remote(messages, stream=stream, **kwargs)
+        # Use asyncio.to_thread for ray.get to avoid blocking
+        response = await asyncio.to_thread(ray.get, response_ref)
 
         return response
 
