@@ -118,8 +118,54 @@ class UnifiedDashboard:
         # Initialize Dask if requested
         if enable_dask:
             try:
-                from dask.distributed import Client
-                self.dask_client = Client()
+                from dask.distributed import LocalCluster, Client
+                # Configure Dask to silence worker warnings
+                import dask
+                import os
+
+                # Set environment variables before cluster creation (workers inherit these)
+                os.environ['DASK_DISTRIBUTED__LOGGING__DISTRIBUTED'] = 'error'
+                os.environ['DASK_LOGGING__DISTRIBUTED'] = 'error'
+
+                dask.config.set({"distributed.worker.daemon": False})
+                dask.config.set({"distributed.logging.distributed": "error"})
+                dask.config.set({"logging.distributed": "error"})
+                dask.config.set({"distributed.admin.tick.interval": "500ms"})
+
+                # Use threads with completely suppressed logging
+                cluster = LocalCluster(
+                    n_workers=1,
+                    threads_per_worker=2,
+                    processes=False,  # Use threads
+                    dashboard_address=f":{dask_dashboard_port}",
+                    silence_logs=logging.CRITICAL,
+                )
+
+                logger.info("📊 Dask cluster using threaded workers (shared logging context)")
+
+                self.dask_client = Client(cluster)
+
+                # Add filter to ALL handlers to block "Task queue depth" warnings
+                # This catches warnings from threaded workers at the handler level
+                class DaskWarningFilter(logging.Filter):
+                    def filter(self, record):
+                        return 'Task queue depth' not in record.getMessage()
+
+                dask_filter = DaskWarningFilter()
+
+                # Apply filter to root logger AND all its handlers
+                logging.root.addFilter(dask_filter)
+                for handler in logging.root.handlers:
+                    handler.addFilter(dask_filter)
+
+                # Apply to all distributed loggers and their handlers
+                for logger_name in ['distributed', 'distributed.worker', 'distributed.scheduler',
+                                   'distributed.core', 'distributed.comm']:
+                    dist_logger = logging.getLogger(logger_name)
+                    dist_logger.addFilter(dask_filter)
+                    dist_logger.setLevel(logging.CRITICAL)
+                    for handler in dist_logger.handlers:
+                        handler.addFilter(dask_filter)
 
                 # Get actual dashboard URL from client (may be on different port if 8787 was taken)
                 if hasattr(self.dask_client, 'dashboard_link'):
@@ -189,20 +235,34 @@ class UnifiedDashboard:
         def network_nodes():
             """Get all Ollama nodes in the network (universal)."""
             try:
-                # Try to get from router's pool
+                # Try to get from router's pool with live health data
                 if self.router and hasattr(self.router, 'ollama_pool') and self.router.ollama_pool:
                     pool = self.router.ollama_pool
                     nodes = []
+
+                    # Get live node performance data from background health checks
+                    node_perf = pool.stats.get("node_performance", {})
+
                     for node in pool.nodes:
                         # Handle both OllamaNode objects and dict formats
                         if isinstance(node, dict):
-                            url = f"http://{node.get('host', 'localhost')}:{node.get('port', 11434)}"
+                            host = node.get('host', 'localhost')
+                            port = node.get('port', 11434)
+                            url = f"http://{host}:{port}"
+                            node_key = f"{host}:{port}"
+
+                            # Get live health data from background health check thread
+                            perf_data = node_perf.get(node_key, {})
+                            is_available = perf_data.get("available", True)
+                            latency_ms = int(perf_data.get("latency_ms", 0))
+                            gpu_free_mem = perf_data.get("gpu_free_mem", 0)
+
                             nodes.append({
                                 "url": url,
-                                "status": "healthy",
-                                "latency_ms": 0,
-                                "load_percent": 0,
-                                "memory_mb": 0,
+                                "status": "healthy" if is_available else "offline",
+                                "latency_ms": latency_ms,
+                                "load_percent": 0,  # TODO: calculate from active_requests
+                                "memory_mb": gpu_free_mem,
                             })
                         else:
                             # OllamaNode object
@@ -388,6 +448,61 @@ class UnifiedDashboard:
             """Prometheus metrics export."""
             return generate_latest()
 
+        @self.app.route("/api/network/events")
+        def network_events():
+            """Get recent network observability events."""
+            try:
+                from sollol.network_observer import get_observer
+
+                observer = get_observer()
+
+                # Get query parameters
+                limit = request.args.get("limit", 100, type=int)
+                backend = request.args.get("backend", None)
+                event_type = request.args.get("event_type", None)
+                min_severity = request.args.get("severity", "info")
+
+                events = observer.get_recent_events(
+                    limit=limit,
+                    backend=backend,
+                    min_severity=min_severity
+                )
+
+                return jsonify({
+                    "events": events,
+                    "total": len(events)
+                })
+            except Exception as e:
+                logger.error(f"Error getting network events: {e}")
+                return jsonify({"error": str(e), "events": []}), 500
+
+        @self.app.route("/api/network/stats")
+        def network_stats():
+            """Get network observability statistics."""
+            try:
+                from sollol.network_observer import get_observer
+
+                observer = get_observer()
+                return jsonify(observer.get_stats())
+            except Exception as e:
+                logger.error(f"Error getting network stats: {e}")
+                return jsonify({"error": str(e)}), 500
+
+        @self.app.route("/api/network/backend_metrics")
+        def backend_metrics():
+            """Get backend performance metrics."""
+            try:
+                from sollol.network_observer import get_observer
+
+                observer = get_observer()
+                backend = request.args.get("backend", None)
+                metrics = observer.get_backend_metrics(backend)
+
+                return jsonify(metrics)
+            except Exception as e:
+                logger.error(f"Error getting backend metrics: {e}")
+                return jsonify({"error": str(e)}), 500
+
         @self.app.route("/api/trace", methods=["POST"])
         def add_trace():
             """Add distributed trace."""
@@ -874,6 +989,90 @@ class UnifiedDashboard:
                     logger.error(f"Applications WebSocket error: {e}")
                     break
 
+        @self.sock.route('/ws/network/ollama_activity')
+        def ws_ollama_network_activity(ws):
+            """WebSocket endpoint for real-time Ollama network activity stream."""
+            logger.info("🔌 Ollama network activity WebSocket connected")
+
+            try:
+                from sollol.network_observer import get_observer, EventType
+
+                observer = get_observer()
+                last_event_count = 0
+
+                while True:
+                    # Get recent Ollama events
+                    ollama_events = [
+                        e for e in observer.get_recent_events(limit=100)
+                        if any(keyword in e["event_type"] for keyword in ["ollama", "node"])
+                    ]
+
+                    # Only send new events
+                    if len(ollama_events) > last_event_count:
+                        new_events = ollama_events[:len(ollama_events) - last_event_count]
+                        for event in reversed(new_events):
+                            ws.send(json.dumps(event))
+
+                    last_event_count = len(ollama_events)
+
+                    # Heartbeat every 5 seconds
+                    if not hasattr(ws, '_last_heartbeat'):
+                        ws._last_heartbeat = 0
+                    if time.time() - ws._last_heartbeat >= 5:
+                        ws.send(json.dumps({
+                            "type": "heartbeat",
+                            "timestamp": time.time(),
+                            "message": "✓ Monitoring Ollama network"
+                        }))
+                        ws._last_heartbeat = time.time()
+
+                    time.sleep(0.5)  # Check for new events every 500ms
+
+            except Exception as e:
+                logger.error(f"Ollama network activity WebSocket error: {e}")
+
+        @self.sock.route('/ws/network/rpc_activity')
+        def ws_rpc_network_activity(ws):
+            """WebSocket endpoint for real-time llama.cpp RPC activity stream."""
+            logger.info("🔌 llama.cpp RPC activity WebSocket connected")
+
+            try:
+                from sollol.network_observer import get_observer, EventType
+
+                observer = get_observer()
+                last_event_count = 0
+
+                while True:
+                    # Get recent RPC events
+                    rpc_events = [
+                        e for e in observer.get_recent_events(limit=100)
+                        if "rpc" in e["event_type"] or "coordinator" in e["event_type"]
+                    ]
+
+                    # Only send new events
+                    if len(rpc_events) > last_event_count:
+                        new_events = rpc_events[:len(rpc_events) - last_event_count]
+                        for event in reversed(new_events):
+                            ws.send(json.dumps(event))
+
+                    last_event_count = len(rpc_events)
+
+                    # Heartbeat every 5 seconds
+                    if not hasattr(ws, '_last_heartbeat'):
+                        ws._last_heartbeat = 0
+                    if time.time() - ws._last_heartbeat >= 5:
+                        ws.send(json.dumps({
+                            "type": "heartbeat",
+                            "timestamp": time.time(),
+                            "message": "✓ Monitoring llama.cpp RPC network"
+                        }))
+                        ws._last_heartbeat = time.time()
+
+                    time.sleep(0.5)  # Check for new events every 500ms
+
+            except Exception as e:
+                logger.error(f"llama.cpp RPC activity WebSocket error: {e}")
+
     def _cleanup_stale_applications(self):
         """Remove applications that haven't sent heartbeat recently."""
         now = time.time()
